# -*- coding: utf-8 -*-
from __future__ import unicode_literals, print_function, absolute_import
from django.core.management.base import BaseCommand
from ttoolly.utils import unicode_to_readable, generate_random_obj
from django.core import serializers
from optparse import make_option

from django.apps import apps
get_model = apps.get_model


class Command(BaseCommand):

    help = ("Write to file the contents of the database as a fixture with "
            "readable unicode text")
    args = 'appname.ModelName'

    def add_arguments(self, parser):
        parser.add_argument('label', metavar='app_label.ModelName')
        parser.add_argument('-f', '--file', dest='path_to_file', default=None,
                            help='Specifies the output file path.')
        parser.add_argument('-r', '--random_text_file', dest='path_to_random_file', default=None,
                            help='Specifies the file with some text for generate random object.')

    def handle(self, *label, **kwargs):
        path_to_file = kwargs.get('path_to_file')
        app_label, model_label = kwargs.get('label').split('.')
        obj_model = get_model(app_label, model_label)
        obj = generate_random_obj(obj_model, filename=kwargs.get('path_to_random_file'), with_save=False)

        """Объект создается без сохранения, поэтому исключаем m2m"""
        fields = [f.name for f in set(obj_model._meta.fields).difference(obj_model._meta.many_to_many)]

        text = unicode_to_readable(
            serializers.serialize('json', [obj, ], indent=4, use_natural_foreign_keys=True, fields=fields))

        if path_to_file:
            with open(path_to_file, 'ab') as f:
                f.write(text.encode('utf-8'))
        else:
            print(text)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from unittest import TextTestResult

from django.conf import settings
from future.utils import PY2
from ttoolly.utils import unicode_to_readable, to_bytes


if getattr(settings, 'COLORIZE_TESTS', False):

    def _getDescription(self, test):
        doc_first_line = test.shortDescription()
        full_text = "\033[38;5;230m" + str(test) + "\033[38;0m"
        class_doc = test.__class__.__doc__
        if class_doc:
            full_text += '\n~~~~~~~~~~\n' + '\n'.join([line.strip() for line in
                                                       to_bytes(class_doc).decode('utf-8').strip('\n ').splitlines()]) + '\n~~~~~~~~~~'
        doc = getattr(test, '_testMethodDoc', '')
        if doc:
            full_text += '\n  ' + '\n  '.join([line.strip() for line in
                                               to_bytes(doc).decode('utf-8').replace('@note: ', '').strip('\n').splitlines()])
        elif self.descriptions and doc_first_line:
            full_text += '\n' + to_bytes(doc_first_line).decode('utf-8')
        return full_text

    TextTestResult.getDescription = _getDescription

if PY2:
    def _printErrorList(self, flavour, errors):
        for test, err in errors:
            self.stream.writeln(self.separator1)
            self.stream.writeln("%s: %s" % (flavour, self.getDescription(test)))
            self.stream.writeln(self.separator2)
            self.stream.writeln("%s" % unicode_to_readable(err))

    TextTestResult.printErrorList = _printErrorList

settings.FILE_UPLOAD_HANDLERS = ['ttoolly.utils.FakeSizeMemoryFileUploadHandler'] + list(settings.FILE_UPLOAD_HANDLERS)



# -*- coding: utf-8 -*-
from django.core.management.base import BaseCommand
try:
    from django.contrib.auth import get_user_model
except ImportError:
    from django.contrib.auth.models import User

    def get_user_model():
        return User


class Command(BaseCommand):

    args = 'password'
    help = "Changes all users passwords to specified (qwerty by default)"

    def add_arguments(self, parser):
        parser.add_argument('-p', '--password', default='qwerty', help='New password. Default: %(default)s')

    def handle(self, *args, **kwargs):
        password = kwargs.get('password')

        for user in get_user_model().objects.all():
            user.set_password(password)
            user.save()



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

import os

from django import forms

from test_project.test_app.models import SomeModel


class SomeModelForm(forms.ModelForm):
    allowed_extensions = ('jpg', 'jpeg', 'png')

    class Meta:
        model = SomeModel
        fields = '__all__'

    def clean_image_field(self):
        value = self.cleaned_data.get('image_field')
        if value:
            ext = os.path.splitext(value.name)[1][1:].lower()
            if ext not in self.allowed_extensions:
                raise forms.ValidationError('Загрузите правильное изображение. Файл, который вы загрузили, '
                                            'поврежден или не является изображением.')
        return value
